@@ -99,6 +99,19 @@ def universal_download(url, output_dir='.', merge=True, info_only=False, **kwarg
         for rel_url in rel_urls:
             urls += [ r1(r'(.*/)', url) + rel_url ]
 
+        # site-relative path
+        rel_urls = []
+        rel_urls += re.findall(r'href="(/[^"]+\.jpe?g)"', page, re.I)
+        rel_urls += re.findall(r'href="(/[^"]+\.png)"', page, re.I)
+        rel_urls += re.findall(r'href="(/[^"]+\.gif)"', page, re.I)
+        for rel_url in rel_urls:
+            urls += [ r1(r'(https?://[^/]+)', url) + rel_url ]
+
+        # sometimes naive
+        urls += re.findall(r'data-original="(https?://[^"]+\.jpe?g)"', page, re.I)
+        urls += re.findall(r'data-original="(https?://[^"]+\.png)"', page, re.I)
+        urls += re.findall(r'data-original="(https?://[^"]+\.gif)"', page, re.I)
+
         # MPEG-DASH MPD
         mpd_urls = re.findall(r'src="(https?://[^"]+\.mpd)"', page)
         for mpd_url in mpd_urls:
